@@ -1,4 +1,5 @@
 from panda3d.core import Datagram, DatagramIterator
+from p3bamboo.BamGlobals import BAMException
 import logging
 
 """
@@ -13,9 +14,29 @@ class BamObject(object):
     def __init__(self, bam_file, bam_version):
         self.bam_file = bam_file
         self.bam_version = bam_version
-        self.extra_data = b''
+        self.extra_data = None
+        self.obj_id = -1
+
+    def to_binary(self, write_version=None):
+        if write_version is None:
+            write_version = self.bam_version
+
+        dg = Datagram()
+        self.write(write_version, dg)
+
+        if self.extra_data:
+            dg.append_data(self.extra_data)
+
+        return dg.get_message()
+
+    def save(self, write_version=None):
+        if self.obj_id == -1:
+            raise BAMException('Cannot save: object ID has not been set.')
+
+        self.bam_file.objects[self.obj_id]['data'] = self.to_binary(write_version)
 
     def load_object(self, obj):
+        self.obj_id = obj['obj_id']
         dg = Datagram(obj['data'])
         di = DatagramIterator(dg)
         self.load(di)
@@ -24,19 +45,7 @@ class BamObject(object):
             self.extra_data = di.get_remaining_bytes()
 
             if self.bam_file.warn_truncated_data:
-                logger.warning('Warning! Loading truncated data for {0}.'.format(obj['handle_name']))
-
-    def write_object(self, write_version, obj):
-        dg = Datagram()
-        self.write(write_version, dg)
-
-        if self.extra_data:
-            dg.append_data(self.extra_data)
-
-            if self.bam_file.warn_truncated_data:
-                logger.warning('Warning! Saving truncated data for {0}.'.format(obj['handle_name']))
-
-        obj['data'] = dg.get_message()
+                logging.warning('Warning! Loading truncated data for {0}.'.format(obj['handle_name']))
 
     def load_type(self, type_constructor, di):
         obj = type_constructor(self.bam_file, self.bam_version)
